@@ -4,8 +4,9 @@
 Chart Basics
 ~~~~~~~~~~~~
 
-This example shows how different types of charts can be added to the scene. A more complex example, showing how to
-combine multiple charts as overlays in the same renderer, is given in :ref:`chart_overlays_example`.
+This example shows how different types of charts can be added to the scene.
+A more complex example, showing how to combine multiple charts as overlays
+in the same renderer, is given in :ref:`chart_overlays_example`.
 """
 
 from __future__ import annotations
@@ -23,20 +24,20 @@ rng = np.random.default_rng(1)  # Seeded random number generator for consistent
 
 # %%
 # This example shows how to create a 2D scatter plot from 100 randomly sampled
-# datapoints. By default, the chart automatically rescales its axes such that
-# all plotted data is visible. By right clicking on the chart you can enable
-# zooming and panning of the chart.
+# datapoints using :func:`~pyvista.Chart2D.scatter`. By default, the chart automatically
+# rescales its axes such that all plotted data is visible. By right clicking on the chart
+# you can enable zooming and panning of the chart.
 
 x = rng.standard_normal(100)
 y = rng.standard_normal(100)
 chart = pv.Chart2D()
-chart.scatter(x, y, size=10, style="+")
+chart.scatter(x, y, size=10, style='+')
 chart.show()
 
 # %%
 # To connect datapoints with lines, you can create a 2D line plot as shown in
-# the example below. You can also dynamically 'zoom in' on the plotted data
-# by specifying a custom axis range yourself.
+# the example below using :func:`~pyvista.Chart2D.line`. You can also dynamically
+# 'zoom in' on the plotted data by specifying a custom axis range yourself.
 
 x = np.linspace(0, 10, 1000)
 y = np.sin(x**2)
@@ -47,7 +48,7 @@ chart.show()
 
 # %%
 # You can also easily combine scatter and line plots using the general
-# :func:`pyvista.Chart2D.plot` function, specifying both the line and marker
+# :func:`~pyvista.Chart2D.plot` function, specifying both the line and marker
 # style at once.
 
 x = np.arange(11)
@@ -58,46 +59,47 @@ chart.plot(x, y, 'x--b')  # Marker style 'x', striped line style '--', blue colo
 chart.show()
 
 # %%
-# The following example shows how to create filled areas between two polylines.
+# The following example shows how to create filled areas between two polylines
+# using :func:`~pyvista.Chart2D.area`.
 
 x = np.linspace(0, 10, 1000)
 y1 = np.cos(x) + np.sin(3 * x)
 y2 = 0.1 * (x - 5)
 chart = pv.Chart2D()
 chart.area(x, y1, y2, color=(0.1, 0.1, 0.9, 0.5))
-chart.line(x, y1, color=(0.9, 0.1, 0.1), width=4, style="--")
-chart.line(x, y2, color=(0.1, 0.9, 0.1), width=4, style="--")
-chart.title = "Area plot"  # Set custom chart title
+chart.line(x, y1, color=(0.9, 0.1, 0.1), width=4, style='--')
+chart.line(x, y2, color=(0.1, 0.9, 0.1), width=4, style='--')
+chart.title = 'Area plot'  # Set custom chart title
 chart.show()
 
 # %%
-# Bar charts are also supported. Multiple bar plots are placed next to each
-# other.
+# Bar charts are also supported using :func:`~pyvista.Chart2D.bar`.
+# Multiple bar plots are placed next to each other.
 
 x = np.arange(1, 13)
 y1 = rng.integers(1e2, 1e4, 12)
 y2 = rng.integers(1e2, 1e4, 12)
 chart = pv.Chart2D()
-chart.bar(x, y1, color="b", label="2020")
-chart.bar(x, y2, color="r", label="2021")
+chart.bar(x, y1, color='b', label='2020')
+chart.bar(x, y2, color='r', label='2021')
 chart.x_axis.tick_locations = x
 chart.x_axis.tick_labels = [
-    "Jan",
-    "Feb",
-    "Mar",
-    "Apr",
-    "May",
-    "Jun",
-    "Jul",
-    "Aug",
-    "Sep",
-    "Oct",
-    "Nov",
-    "Dec",
+    'Jan',
+    'Feb',
+    'Mar',
+    'Apr',
+    'May',
+    'Jun',
+    'Jul',
+    'Aug',
+    'Sep',
+    'Oct',
+    'Nov',
+    'Dec',
 ]
-chart.x_label = "Month"
-chart.y_axis.tick_labels = "2e"
-chart.y_label = "# incidents"
+chart.x_label = 'Month'
+chart.y_axis.tick_labels = '2e'
+chart.y_label = '# incidents'
 chart.show()
 
 # %%
@@ -106,21 +108,22 @@ chart.show()
 
 x = np.arange(1, 11)
 ys = [rng.integers(1, 11, 10) for _ in range(5)]
-labels = [f"Machine {i}" for i in range(5)]
+labels = [f'Machine {i}' for i in range(5)]
 chart = pv.Chart2D()
 chart.bar(x, ys, label=labels)
 chart.x_axis.tick_locations = x
-chart.x_label = "Configuration"
-chart.y_label = "Production"
+chart.x_label = 'Configuration'
+chart.y_label = 'Production'
 chart.grid = False  # Disable the grid lines
 chart.show()
 
 # %%
-# In a similar way, you can stack multiple area plots on top of each other.
+# In a similar way, you can stack multiple area plots on top of
+# each other using :func:`~pyvista.Chart2D.stack`.
 
 x = np.arange(0, 11)
 ys = [rng.integers(1, 11, 11) for _ in range(5)]
-labels = [f"Segment {i}" for i in range(5)]
+labels = [f'Segment {i}' for i in range(5)]
 chart = pv.Chart2D()
 chart.stack(x, ys, labels=labels)
 chart.show()
@@ -128,19 +131,20 @@ chart.show()
 # %%
 # Beside the flexible Chart2D used in the previous examples, there are a couple
 # other dedicated charts you can create. The example below shows how a pie
-# chart can be created.
+# chart can be created using :class:`~pyvista.ChartPie`.
 
 data = np.array([8.4, 6.1, 2.7, 2.4, 0.9])
 chart = pv.ChartPie(data)
-chart.plot.labels = [f"slice {i}" for i in range(len(data))]
+chart.plot.labels = [f'slice {i}' for i in range(len(data))]
 chart.show()
 
 # %%
-# To summarize statistics of datasets, you can easily create a boxplot.
+# To summarize statistics of datasets, you can easily create a boxplot
+# using :class:`~pyvista.ChartBox`.
 
 data = [rng.poisson(lam, 20) for lam in range(2, 12, 2)]
 chart = pv.ChartBox(data)
-chart.plot.labels = [f"Experiment {i}" for i in range(len(data))]
+chart.plot.labels = [f'Experiment {i}' for i in range(len(data))]
 chart.show()
 
 # %%
@@ -159,11 +163,11 @@ alphas = [0.5 + i for i in range(5)]
 betas = [*reversed(alphas)]
 N = int(1e4)
 data = [rng.beta(alpha, beta, N) for alpha, beta in zip(alphas, betas)]
-labels = [f"$\\alpha={alpha:.1f}\\,;\\,\\beta={beta:.1f}$" for alpha, beta in zip(alphas, betas)]
+labels = [f'$\\alpha={alpha:.1f}\\,;\\,\\beta={beta:.1f}$' for alpha, beta in zip(alphas, betas)]
 ax.violinplot(data)
 ax.set_xticks(np.arange(1, 1 + len(labels)))
 ax.set_xticklabels(labels)
-ax.set_title("$B(\\alpha, \\beta)$")
+ax.set_title('$B(\\alpha, \\beta)$')
 
 # Next, embed the figure into a pyvista plotting window
 p = pv.Plotter()
@@ -171,3 +175,5 @@ chart = pv.ChartMPL(f)
 chart.background_color = 'w'
 p.add_chart(chart)
 p.show()
+# %%
+# .. tags:: plot
