@@ -1,9 +1,11 @@
 """
-.. _gif_movie_example:
+.. _gif_example:
 
 Create a GIF Movie
 ~~~~~~~~~~~~~~~~~~
 Generate a moving gif from an active plotter.
+This example uses :meth:`~pyvista.Plotter.open_gif` and
+:meth:`~pyvista.Plotter.write_frame` to create the gif.
 
 .. note::
    Use ``lighting=False`` to reduce the size of the color space to avoid
@@ -32,7 +34,7 @@ z = np.sin(r)
 
 # Create and structured surface
 grid = pv.StructuredGrid(x, y, z)
-grid["Height"] = z.ravel()
+grid['Height'] = z.ravel()
 grid.plot()
 
 
@@ -45,14 +47,14 @@ grid.plot()
 plotter = pv.Plotter(notebook=False, off_screen=True)
 plotter.add_mesh(
     grid,
-    scalars="Height",
+    scalars='Height',
     lighting=False,
     show_edges=True,
     clim=[-1, 1],
 )
 
 # Open a gif
-plotter.open_gif("wave.gif")
+plotter.open_gif('wave.gif')
 
 # Update Z and write a frame for each updated position
 nframe = 15
@@ -60,9 +62,11 @@ for phase in np.linspace(0, 2 * np.pi, nframe + 1)[:nframe]:
     z = np.sin(r + phase)
     # Update values inplace
     grid.points[:, -1] = z.ravel()
-    grid["Height"] = z.ravel()
+    grid['Height'] = z.ravel()
     # Write a frame. This triggers a render.
     plotter.write_frame()
 
 # Closes and finalizes movie
 plotter.close()
+# %%
+# .. tags:: plot
