@@ -1,5 +1,5 @@
 """
-.. _movie_glyph_example:
+.. _movie_glyphs_example:
 
 Save a Movie Using Glyphs
 ~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -51,7 +51,7 @@ plotter.add_mesh(
 )
 
 # Open a gif
-plotter.open_gif("glyph_wave.gif")
+plotter.open_gif('glyph_wave.gif')
 
 # Update Z and write a frame for each updated mesh
 nframe = 30
@@ -70,3 +70,5 @@ for phase in np.linspace(0, 2 * np.pi, nframe + 1)[:nframe]:
 
 # Close and finalize the gif
 plotter.close()
+# %%
+# .. tags:: plot
