@@ -1,4 +1,6 @@
 """
+.. _screenshot_example:
+
 Saving Screenshots
 ~~~~~~~~~~~~~~~~~~
 """
@@ -21,7 +23,7 @@ mesh = pv.read(filename)
 # using the :class:`pyvista.Plotter`:
 
 plotter = pv.Plotter(off_screen=True)
-plotter.add_mesh(mesh, color="orange")
+plotter.add_mesh(mesh, color='orange')
 plotter.show(screenshot='airplane.png')
 
 # %%
@@ -29,3 +31,5 @@ plotter.show(screenshot='airplane.png')
 
 plt.imshow(plotter.image)
 plt.show()
+# %%
+# .. tags:: plot
