@@ -17,10 +17,10 @@ from pyvista.trame.ui import plotter_ui
 
 pv.OFF_SCREEN = True
 
-server = get_server(client_type="vue3")
+server = get_server(client_type='vue3')
 state, ctrl = server.state, server.controller
 
-state.trame__title = "File Viewer"
+state.trame__title = 'File Viewer'
 ctrl.on_server_ready.add(ctrl.view_update)
 
 # -----------------------------------------------------------------------------
@@ -30,8 +30,8 @@ ctrl.on_server_ready.add(ctrl.view_update)
 pl = pv.Plotter()
 
 
-@server.state.change("file_exchange")
-def handle(file_exchange, **kwargs):
+@server.state.change('file_exchange')
+def handle(file_exchange, **kwargs):  # noqa: ARG001
     # Vuetify3 File Input always returns list
     if file_exchange and len(file_exchange) > 0:
         file = ClientFile(file_exchange[0])
@@ -54,33 +54,33 @@ def handle(file_exchange, **kwargs):
 # Web App setup
 # -----------------------------------------------------------------------------
 
-state.trame__title = "File Viewer"
+state.trame__title = 'File Viewer'
 
 with SinglePageLayout(server) as layout:
-    layout.title.set_text("File Viewer")
+    layout.title.set_text('File Viewer')
     with layout.toolbar:
         vuetify3.VSpacer()
         vuetify3.VFileInput(
             show_size=True,
             chips=True,
             truncate_length=25,
-            v_model=("file_exchange", None),
-            density="compact",
+            v_model=('file_exchange', None),
+            density='compact',
             hide_details=True,
-            style="max-width: 300px;",
+            style='max-width: 300px;',
         )
         vuetify3.VProgressLinear(
             indeterminate=True,
             absolute=True,
             bottom=True,
-            active=("trame__busy",),
+            active=('trame__busy',),
         )
 
     with layout.content:
         with vuetify3.VContainer(
             fluid=True,
-            classes="pa-0 fill-height",
-            style="position: relative;",
+            classes='pa-0 fill-height',
+            style='position: relative;',
         ):
             # Use PyVista UI template for Plotters
             view = plotter_ui(pl)
