@@ -1,13 +1,16 @@
-"""Module containing pyvista implementation of vtkAxes."""
+"""Module containing pyvista implementation of :vtk:`vtkAxes`."""
 
 from __future__ import annotations
 
+from pyvista._deprecate_positional_args import _deprecate_positional_args
+from pyvista.core.utilities.misc import _NoNewAttrMixin
+
 from . import _vtk
 from .actor import Actor
 from .axes_actor import AxesActor
 
 
-class Axes(_vtk.vtkAxes):
+class Axes(_NoNewAttrMixin, _vtk.DisableVtkSnakeCase, _vtk.vtkAxes):
     """PyVista wrapper for the VTK Axes class.
 
     Parameters
@@ -33,12 +36,13 @@ class Axes(_vtk.vtkAxes):
 
     """
 
-    def __init__(
+    @_deprecate_positional_args
+    def __init__(  # noqa: PLR0917
         self,
-        show_actor=False,
+        show_actor: bool = False,  # noqa: FBT001, FBT002
         actor_scale=1,
         line_width=1.0,
-        symmetric=False,
+        symmetric: bool = False,  # noqa: FBT001, FBT002
     ):  # numpydoc ignore=PR01,RT01
         """Initialize a new axes descriptor."""
         super().__init__()
@@ -74,7 +78,7 @@ class Axes(_vtk.vtkAxes):
         return self.GetOrigin()
 
     @origin.setter
-    def origin(self, value):  # numpydoc ignore=GL08
+    def origin(self, value):
         self.SetOrigin(value)
 
     def show_actor(self):
@@ -85,6 +89,7 @@ class Axes(_vtk.vtkAxes):
         >>> import pyvista as pv
         >>> axes = pv.Axes()
         >>> axes.show_actor()
+
         """
         self.actor.visibility = True
 
@@ -96,6 +101,7 @@ class Axes(_vtk.vtkAxes):
         >>> import pyvista as pv
         >>> axes = pv.Axes()
         >>> axes.hide_actor()
+
         """
         self.actor.visibility = False
 
@@ -107,6 +113,7 @@ class Axes(_vtk.vtkAxes):
         >>> import pyvista as pv
         >>> axes = pv.Axes()
         >>> axes.show_symmetric()
+
         """
         self.SymmetricOn()
 
@@ -118,11 +125,12 @@ class Axes(_vtk.vtkAxes):
         >>> import pyvista as pv
         >>> axes = pv.Axes()
         >>> axes.hide_symmetric()
+
         """
         self.SymmetricOff()
 
     def __del__(self):
         """Clean the attributes of the class."""
-        self.axes_actor = None
-        self.actor = None
-        self.mapper = None
+        self.axes_actor = None  # type: ignore[assignment]
+        self.actor = None  # type: ignore[assignment]
+        self.mapper = None  # type: ignore[assignment]
