@@ -18,11 +18,16 @@ def __getattr__(name):
         try:
             value = inspect.getattr_static(module, name)
         except AttributeError:
-            raise AttributeError(
-                f'Module `pyvista.plotting.plotting` has been deprecated and we could not automatically find `{name}`.',
-            ) from None
+            msg = (
+                f'Module `pyvista.plotting.plotting` has been deprecated and we could not '
+                f'automatically find `{name}`.'
+            )
+            raise AttributeError(msg) from None
     import_path = f'from pyvista.plotting import {name}'
-    message = f'The `pyvista.plotting.plotting` module has been deprecated. `{name}` is now imported as: `{import_path}`.'
+    message = (
+        f'The `pyvista.plotting.plotting` module has been deprecated. '
+        f'`{name}` is now imported as: `{import_path}`.'
+    )
     warnings.warn(
         message,
         PyVistaDeprecationWarning,
