@@ -1,4 +1,3 @@
-# ruff: noqa: D102,D103,D107
 """PyVista Trame Viewer class for a Vue 3 client.
 
 This class, derived from `pyvista.trame.ui.base_viewer`,
@@ -20,7 +19,7 @@ from pyvista.trame.views import PyVistaRemoteView
 
 from .base_viewer import BaseViewer
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from trame_client.ui.core import AbstractLayout
 
 
@@ -108,6 +107,7 @@ class Viewer(BaseViewer):
         -------
         VAppLayout (vue3)
             A layout this viewer can be embedded in.
+
         """
         return VAppLayout(*args, **kwargs)
 
@@ -136,14 +136,14 @@ class Viewer(BaseViewer):
         with vuetify.VRow(
             v_show=v_show,
             classes='pa-0 ma-0 align-center fill-height',
-            style="flex-wrap: nowrap",
+            style='flex-wrap: nowrap',
         ) as row:
             server = row.server
             # Listen to state changes
-            server.state.change(self.EDGES)(self.on_edge_visiblity_change)
-            server.state.change(self.GRID)(self.on_grid_visiblity_change)
-            server.state.change(self.OUTLINE)(self.on_outline_visiblity_change)
-            server.state.change(self.AXIS)(self.on_axis_visiblity_change)
+            server.state.change(self.EDGES)(self.on_edge_visibility_change)
+            server.state.change(self.GRID)(self.on_grid_visibility_change)
+            server.state.change(self.OUTLINE)(self.on_outline_visibility_change)
+            server.state.change(self.AXIS)(self.on_axis_visibility_change)
             server.state.change(self.SERVER_RENDERING)(self.on_rendering_mode_change)
             server.state.change(self.PARALLEL)(self.on_parallel_projection_change)
             vuetify.VDivider(vertical=True, classes='mr-1')
@@ -200,17 +200,19 @@ class Viewer(BaseViewer):
                 checkbox(
                     model=(self.SERVER_RENDERING, default_server_rendering),
                     icons=('mdi-dns', 'mdi-open-in-app'),
-                    tooltip=f"Toggle rendering mode ({{{{ {self.SERVER_RENDERING} ? 'remote' : 'local' }}}})",
+                    tooltip=f'Toggle rendering mode '
+                    f"({{{{ {self.SERVER_RENDERING} ? 'remote' : 'local' }}}})",
                 )
             with vuetify.VRow(
                 v_show=(self.SERVER_RENDERING, default_server_rendering),
                 classes='pa-0 ma-0 align-center fill-height',
-                style="flex-wrap: nowrap; flex: unset",
+                style='flex-wrap: nowrap; flex: unset',
             ):
                 checkbox(
                     model=(self.PARALLEL, False),
                     icons=('mdi-camera-off', 'mdi-camera-switch'),
-                    tooltip=f"Toggle parallel projection ({{{{ {self.PARALLEL} ? 'on' : 'off' }}}})",
+                    tooltip=f'Toggle parallel projection '
+                    f"({{{{ {self.PARALLEL} ? 'on' : 'off' }}}})",
                 )
 
                 def attach_screenshot():
@@ -218,7 +220,9 @@ class Viewer(BaseViewer):
 
                 button(
                     # Must use single-quote string for JS here
-                    click=f"utils.download('screenshot.png', trigger('{server.trigger_name(attach_screenshot)}'), 'image/png')",
+                    click="utils.download('screenshot.png', "
+                    f"trigger('{server.trigger_name(attach_screenshot)}'), "
+                    "'image/png')",
                     icon='mdi-file-png-box',
                     tooltip='Save screenshot',
                 )
@@ -228,7 +232,9 @@ class Viewer(BaseViewer):
 
             button(
                 # Must use single-quote string for JS here
-                click=f"utils.download('scene-export.html', trigger('{server.trigger_name(attach_export)}'), 'application/octet-stream')",
+                click="utils.download('scene-export.html', "
+                f"trigger('{server.trigger_name(attach_export)}'), "
+                "'application/octet-stream')",
                 icon='mdi-download',
                 tooltip='Export scene as HTML',
             )
@@ -281,9 +287,8 @@ class Viewer(BaseViewer):
         if mode is None:
             mode = self.plotter._theme.trame.default_mode
         if mode not in self.VALID_UI_MODES:
-            raise ValueError(
-                f'`{mode}` is not a valid mode choice. Use one of: {self.VALID_UI_MODES}',
-            )
+            msg = f'`{mode}` is not a valid mode choice. Use one of: {self.VALID_UI_MODES}'
+            raise ValueError(msg)
         if mode != 'trame':
             default_server_rendering = mode == 'server'
 
@@ -297,9 +302,9 @@ class Viewer(BaseViewer):
             # Initialize state variables
             server.state[self.EDGES] = False
             server.state[self.GRID] = self.plotter.renderer.cube_axes_actor is not None
-            server.state[self.OUTLINE] = hasattr(self.plotter.renderer, '_box_object')
+            server.state[self.OUTLINE] = self.plotter.renderer._box_object is not None
             server.state[self.AXIS] = (
-                hasattr(self.plotter.renderer, 'axes_widget')
+                self.plotter.renderer.axes_widget is not None
                 and self.plotter.renderer.axes_widget.GetEnabled()
             )
             server.state[self.SERVER_RENDERING] = default_server_rendering
@@ -311,7 +316,7 @@ class Viewer(BaseViewer):
                 ) as self.menu:
                     with vuetify.VRow(
                         classes='pa-0 ma-0 align-center fill-height',
-                        style="flex-wrap: nowrap",
+                        style='flex-wrap: nowrap',
                     ):
                         button(
                             click=f'{self.SHOW_UI}=!{self.SHOW_UI}',
