@@ -23,9 +23,18 @@ def test_plotting_top_namespace(name):
 def test_common_plotting_import_paths():
     # These are `pyvista.plotting.plotting` imports found via search on GitHub
     # across multiple public repositories
-    with pytest.warns(PyVistaDeprecationWarning):
+    with pytest.warns(
+        PyVistaDeprecationWarning,
+        match='The `pyvista.plotting.plotting` module has been deprecated',
+    ):
         from pyvista.plotting.plotting import _ALL_PLOTTERS  # noqa: F401
-    with pytest.warns(PyVistaDeprecationWarning):
+    with pytest.warns(
+        PyVistaDeprecationWarning,
+        match='The `pyvista.plotting.plotting` module has been deprecated',
+    ):
         from pyvista.plotting.plotting import BasePlotter  # noqa: F401
-    with pytest.warns(PyVistaDeprecationWarning):
+    with pytest.warns(
+        PyVistaDeprecationWarning,
+        match='The `pyvista.plotting.plotting` module has been deprecated',
+    ):
         from pyvista.plotting.plotting import Plotter  # noqa: F401
