@@ -32,15 +32,19 @@ try:
     from pyvista.trame.views import PyVistaRemoteLocalView
     from pyvista.trame.views import PyVistaRemoteView
     from pyvista.trame.views import _BasePyVistaView
-except:
+except ImportError:
     has_trame = False
 
-# skip all tests if VTK<9.1.0
-if pv.vtk_version_info < (9, 1):
-    pytestmark = pytest.mark.skip
-else:
-    skip_no_trame = pytest.mark.skipif(not has_trame, reason="Requires trame")
-    pytestmark = [skip_no_trame, pytest.mark.skip_plotting]
+pytestmark = [
+    pytest.mark.needs_vtk_version(9, 1),
+    pytest.mark.skipif(not has_trame, reason='Requires trame'),
+    pytest.mark.skip_plotting,
+    pytest.mark.skip_check_gc,
+    pytest.mark.filterwarnings(
+        r'ignore:It is recommended to use web\.AppKey instances for '
+        r'keys:aiohttp.web_exceptions.NotAppKeyWarning'
+    ),
+]
 
 
 def test_set_jupyter_backend_trame():
@@ -71,6 +75,9 @@ def test_base_viewer_ui():
 
 
 @pytest.mark.parametrize('client_type', ['vue2', 'vue3'])
+@pytest.mark.filterwarnings(
+    'ignore:Suppress rendering on the plotter is changed to .*:UserWarning'
+)
 def test_trame_plotter_ui(client_type):
     # give different names for servers so different instances are created
     name = f'{pv.global_theme.trame.jupyter_server_name}-{client_type}'
@@ -87,7 +94,7 @@ def test_trame_plotter_ui(client_type):
 
     # Test invalid mode
     mode = 'invalid'
-    with pytest.raises(ValueError, match=f"`{mode}` is not a valid mode choice. Use one of: (.*)"):
+    with pytest.raises(ValueError, match=f'`{mode}` is not a valid mode choice. Use one of: (.*)'):
         ui = plotter_ui(pl, mode=mode, server=server)
 
     # Test when mode and server are None
@@ -124,32 +131,31 @@ def test_trame(client_type):
 
     orig_value = actor.prop.show_edges
     server.state[viewer.EDGES] = not orig_value
-    viewer.on_edge_visiblity_change(**server.state.to_dict())
+    viewer.on_edge_visibility_change(**server.state.to_dict())
     assert actor.prop.show_edges != orig_value
 
     server.state[viewer.GRID] = True
     assert len(pl.actors) == 1
-    viewer.on_grid_visiblity_change(**server.state.to_dict())
+    viewer.on_grid_visibility_change(**server.state.to_dict())
     assert len(pl.actors) == 2
     server.state[viewer.GRID] = False
-    viewer.on_grid_visiblity_change(**server.state.to_dict())
+    viewer.on_grid_visibility_change(**server.state.to_dict())
     assert len(pl.actors) == 1
 
     server.state[viewer.OUTLINE] = True
     assert len(pl.actors) == 1
-    viewer.on_outline_visiblity_change(**server.state.to_dict())
+    viewer.on_outline_visibility_change(**server.state.to_dict())
     assert len(pl.actors) == 2
     server.state[viewer.OUTLINE] = False
-    viewer.on_outline_visiblity_change(**server.state.to_dict())
+    viewer.on_outline_visibility_change(**server.state.to_dict())
     assert len(pl.actors) == 1
 
     server.state[viewer.AXIS] = True
-    assert not hasattr(pl.renderer, 'axes_actor')
-    viewer.on_axis_visiblity_change(**server.state.to_dict())
-    assert hasattr(pl.renderer, 'axes_actor')
+    assert pl.renderer.axes_actor is None
+    viewer.on_axis_visibility_change(**server.state.to_dict())
+    assert pl.renderer.axes_actor is not None
     server.state[viewer.AXIS] = False
-    viewer.on_axis_visiblity_change(**server.state.to_dict())
-    assert not pl.renderer.axes_widget.GetEnabled()
+    viewer.on_axis_visibility_change(**server.state.to_dict())
 
     server.state[viewer.SERVER_RENDERING] = False
     viewer.on_rendering_mode_change(**server.state.to_dict())
@@ -185,32 +191,32 @@ def test_trame_custom_menu_items(client_type):
     viewer = get_viewer(pl, server=server)
 
     # setup vuetify items
-    slider = vue2_slider if client_type == "vue2" else vue3_slider
-    text_field = vue2_text_field if client_type == "vue2" else vue3_text_field
-    select = vue2_select if client_type == "vue2" else vue3_select
-    divider = vue2_divider if client_type == "vue2" else vue3_divider
+    slider = vue2_slider if client_type == 'vue2' else vue3_slider
+    text_field = vue2_text_field if client_type == 'vue2' else vue3_text_field
+    select = vue2_select if client_type == 'vue2' else vue3_select
+    divider = vue2_divider if client_type == 'vue2' else vue3_divider
 
     # vuetify items to pass as argument
     def custom_tools():
         divider(vertical=True, classes='mx-1')
         slider(
-            ("resolution", 3),
-            "Resolution slider",
+            ('resolution', 3),
+            'Resolution slider',
             min=3,
             max=20,
             step=1,
         )
-        text_field(("resolution", 3), "Resolution value", type="number")
+        text_field(('resolution', 3), 'Resolution value', type='number')
         divider(vertical=True, classes='mx-1')
         select(
-            model=("visibility", "Show"),
-            tooltip="Toggle visibility",
-            items=['Visibility', ["Hide", "Show"]],
+            model=('visibility', 'Show'),
+            tooltip='Toggle visibility',
+            items=['Visibility', ['Hide', 'Show']],
         )
 
     with viewer.make_layout(server, template_name=pl._id_name):
         viewer.ui(
-            mode="trame",
+            mode='trame',
             default_server_rendering=True,
             collapse_menu=False,
             add_menu_items=custom_tools,
@@ -222,19 +228,19 @@ def test_trame_custom_menu_items(client_type):
     state, ctrl = server.state, server.controller
     ctrl.view_update = widget.viewer.update
 
-    @state.change("resolution")
-    def update_resolution(resolution, **kwargs):
+    @state.change('resolution')
+    def update_resolution(resolution, **kwargs):  # noqa: ARG001
         algo.resolution = resolution
         ctrl.view_update()
 
-    @state.change("visibility")
-    def set_visibility(visibility, **kwargs):
-        toggle = {"Hide": 0, "Show": 1}
+    @state.change('visibility')
+    def set_visibility(visibility, **kwargs):  # noqa: ARG001
+        toggle = {'Hide': 0, 'Show': 1}
         mesh_actor.visibility = toggle[visibility]
         ctrl.view_update()
 
-    assert server.state["resolution"] == 3
-    server.state.update({"resolution": 5, "visibility": "Hide"})
+    assert server.state['resolution'] == 3
+    server.state.update({'resolution': 5, 'visibility': 'Hide'})
     server.state.flush()
     assert algo.resolution == 5
     assert not mesh_actor.visibility
@@ -269,11 +275,13 @@ def test_trame_closed_plotter():
     pl = pv.Plotter(notebook=True)
     pl.add_mesh(pv.Cone())
     pl.close()
-    with pytest.raises(RuntimeError, match='The render window for this plotter has been destroyed'):
+    with pytest.raises(
+        RuntimeError, match='The render window for this plotter has been destroyed'
+    ):
         PyVistaRemoteLocalView(pl)
 
 
-@pytest.mark.skipif(True, reason="#5262")
+@pytest.mark.skipif(True, reason='#5262')
 def test_trame_views():
     server = get_server('foo')
 
@@ -317,7 +325,7 @@ def test_trame_jupyter_custom_size():
 
 
 def test_trame_jupyter_custom_handler():
-    def handler(viewer, src, **kwargs):
+    def handler(viewer, src, **kwargs):  # noqa: ARG001
         return IFrame(src, '75%', '500px')
 
     plotter = pv.Plotter(notebook=True)
@@ -344,7 +352,7 @@ def test_trame_int64():
     assert isinstance(widget, Widget)
 
 
-@pytest.mark.skip_plotting()
+@pytest.mark.skip_plotting
 def test_trame_export_html(tmpdir):
     filename = str(tmpdir.join('tmp.html'))
     plotter = pv.Plotter()
@@ -353,8 +361,8 @@ def test_trame_export_html(tmpdir):
     assert Path(filename).is_file()
 
 
-def test_export_single(tmpdir, skip_check_gc):
-    filename = str(tmpdir.mkdir("tmpdir").join('scene-single'))
+def test_export_single(tmpdir):
+    filename = str(tmpdir.mkdir('tmpdir').join('scene-single'))
     data = examples.load_airplane()
     # Create the scene
     plotter = pv.Plotter()
@@ -364,8 +372,8 @@ def test_export_single(tmpdir, skip_check_gc):
     assert Path(f'{filename}').is_file()
 
 
-def test_export_multi(tmpdir, skip_check_gc):
-    filename = str(tmpdir.mkdir("tmpdir").join('scene-multi'))
+def test_export_multi(tmpdir):
+    filename = str(tmpdir.mkdir('tmpdir').join('scene-multi'))
     multi = pv.MultiBlock()
     # Add examples
     multi.append(examples.load_ant())
@@ -381,8 +389,8 @@ def test_export_multi(tmpdir, skip_check_gc):
     assert Path(f'{filename}').is_file()
 
 
-def test_export_texture(tmpdir, skip_check_gc):
-    filename = str(tmpdir.mkdir("tmpdir").join('scene-texture'))
+def test_export_texture(tmpdir):
+    filename = str(tmpdir.mkdir('tmpdir').join('scene-texture'))
     data = examples.load_globe()
     texture = examples.load_globe_texture()
     # Create the scene
@@ -393,8 +401,8 @@ def test_export_texture(tmpdir, skip_check_gc):
     assert Path(f'{filename}').is_file()
 
 
-def test_export_verts(tmpdir, skip_check_gc):
-    filename = str(tmpdir.mkdir("tmpdir").join('scene-verts'))
+def test_export_verts(tmpdir):
+    filename = str(tmpdir.mkdir('tmpdir').join('scene-verts'))
     data = pv.PolyData(np.random.default_rng().random((100, 3)))
     # Create the scene
     plotter = pv.Plotter()
@@ -404,8 +412,8 @@ def test_export_verts(tmpdir, skip_check_gc):
     assert Path(f'{filename}').is_file()
 
 
-def test_export_color(tmpdir, skip_check_gc):
-    filename = str(tmpdir.mkdir("tmpdir").join('scene-color'))
+def test_export_color(tmpdir):
+    filename = str(tmpdir.mkdir('tmpdir').join('scene-color'))
     data = examples.load_airplane()
     # Create the scene
     plotter = pv.Plotter()
@@ -415,9 +423,20 @@ def test_export_color(tmpdir, skip_check_gc):
     assert Path(f'{filename}').is_file()
 
 
-def test_embeddable_widget(skip_check_gc):
+def test_embeddable_widget():
     plotter = pv.Plotter(notebook=True)
     plotter.add_mesh(pv.Sphere())
     widget = plotter.show(jupyter_backend='html', return_viewer=True)
     # Basically just assert that it didn't error out
     assert isinstance(widget, EmbeddableWidget)
+
+
+def test_ipywidgets_raises(monkeypatch: pytest.MonkeyPatch):
+    from pyvista.trame import jupyter
+
+    monkeypatch.setattr(jupyter, 'HTML', object)
+    with pytest.raises(ImportError, match='Please install `ipywidgets`.'):
+        jupyter.Widget(viewer=None, src=None)
+
+    with pytest.raises(ImportError, match='Please install `ipywidgets`.'):
+        jupyter.EmbeddableWidget(plotter=None, width=None, height=None)
