@@ -6,7 +6,7 @@ import pyvista as pv
 from pyvista.plotting.mapper import PointGaussianMapper
 
 
-@pytest.fixture()
+@pytest.fixture
 def mapper(sphere):
     sphere['array'] = sphere.points[:, 2]
     pl = pv.Plotter()
