@@ -11,7 +11,11 @@ import pyvista as pv
 configuration = [
     ('position', (1, 1, 1), 'SetPosition'),
     ('focal_point', (2, 2, 2), 'SetFocalPoint'),
-    ('model_transform_matrix', np.arange(4 * 4).reshape(4, 4), 'SetModelTransformMatrix'),
+    (
+        'model_transform_matrix',
+        np.arange(4 * 4).reshape(4, 4),
+        'SetModelTransformMatrix',
+    ),
     ('thickness', 1, 'SetThickness'),
     ('parallel_scale', 2, 'SetParallelScale'),
     ('up', (0, 0, 1), 'SetViewUp'),
@@ -21,15 +25,14 @@ configuration = [
 ]
 
 
-@pytest.fixture()
+@pytest.fixture
 def camera():
     return pv.Camera()
 
 
-@pytest.fixture()
+@pytest.fixture
 def paraview_pvcc():
     """Fixture returning a paraview camera file with values of the position"""
-
     tmp = """
     <PVCameraConfiguration description="ParaView camera configuration" version="1.0">
       <Proxy group="views" type="RenderView" id="6395" servers="21">
@@ -67,7 +70,7 @@ def paraview_pvcc():
           <Domain name="bool" id="6395.CameraParallelProjection.bool"/>
         </Property>
       </Proxy>
-    </PVCameraConfiguration>"""
+    </PVCameraConfiguration>"""  # noqa: E501
     position = [10.519087611966333, 40.74973775632195, -20.24019652397463]
     focal = [15.335762892470676, -26.960151717473682, 17.860905595181094]
     view_up = [0.2191945908188539, -0.4665856879512876, -0.8568847805596613]
@@ -75,7 +78,15 @@ def paraview_pvcc():
     parallel_scale = 20.147235678333413
     projection = False
 
-    return io.StringIO(tmp), position, focal, view_up, view_angle, parallel_scale, projection
+    return (
+        io.StringIO(tmp),
+        position,
+        focal,
+        view_up,
+        view_angle,
+        parallel_scale,
+        projection,
+    )
 
 
 def test_invalid_init():
@@ -94,7 +105,7 @@ def test_camera_from_paraview_pvcc(paraview_pvcc):
 
 
 def test_camera_to_paraview_pvcc(camera, tmp_path):
-    fname = tmp_path / "test.pvcc"
+    fname = tmp_path / 'test.pvcc'
     camera.to_paraview_pvcc(fname)
     assert fname.exists()
     ocamera = pv.Camera.from_paraview_pvcc(fname)
@@ -135,13 +146,13 @@ def test_distance(camera):
 
 
 def test_thickness(camera):
-    thickness = np.random.default_rng().random(1)
+    thickness = np.random.default_rng().random()
     camera.thickness = thickness
     assert camera.thickness == thickness
 
 
 def test_parallel_scale(camera):
-    parallel_scale = np.random.default_rng().random(1)
+    parallel_scale = np.random.default_rng().random()
     camera.parallel_scale = parallel_scale
     assert camera.parallel_scale == parallel_scale
 
@@ -149,7 +160,7 @@ def test_parallel_scale(camera):
 def test_zoom(camera):
     camera.enable_parallel_projection()
     orig_scale = camera.parallel_scale
-    zoom = np.random.default_rng().random(1)
+    zoom = np.random.default_rng().random()
     camera.zoom(zoom)
     assert camera.parallel_scale == orig_scale / zoom
 
@@ -173,14 +184,14 @@ def test_disable_parallel_projection(camera):
 
 
 def test_clipping_range(camera):
-    near_point = np.random.default_rng().random(1)
-    far_point = near_point + np.random.default_rng().random(1)
+    near_point = np.random.default_rng().random()
+    far_point = near_point + np.random.default_rng().random()
     points = (near_point, far_point)
     camera.clipping_range = points
     assert camera.GetClippingRange() == points
     assert camera.clipping_range == points
 
-    far_point = near_point - np.random.default_rng().random(1)
+    far_point = near_point - np.random.default_rng().random()
     points = (near_point, far_point)
     with pytest.raises(ValueError):  # noqa: PT011
         camera.clipping_range = points
@@ -295,3 +306,29 @@ def test_copy():
 
     deep = camera.copy()
     assert deep == camera
+
+
+def test_repr(camera):
+    assert 'Camera' in repr(camera)
+    assert 'Position' in repr(camera)
+    assert 'Focal Point' in repr(camera)
+    assert 'Parallel Projection' in repr(camera)
+    assert 'Distance' in repr(camera)
+    assert 'Thickness' in repr(camera)
+    assert 'Parallel Scale' in repr(camera)
+    assert 'Clipping Range' in repr(camera)
+    assert 'View Angle' in repr(camera)
+    assert 'Roll' in repr(camera)
+
+
+def test_str(camera):
+    assert 'Camera' in str(camera)
+    assert 'Position' in str(camera)
+    assert 'Focal Point' in str(camera)
+    assert 'Parallel Projection' in str(camera)
+    assert 'Distance' in str(camera)
+    assert 'Thickness' in str(camera)
+    assert 'Parallel Scale' in str(camera)
+    assert 'Clipping Range' in str(camera)
+    assert 'View Angle' in str(camera)
+    assert 'Roll' in str(camera)
